@@ -92,6 +92,12 @@ class Instances(ApiWrapper):
         resp = self.creator_api.post(type_name, json=definition)
         return resp
 
+    def delete(self, uuid, uninstall_reason="<Not specified>"):
+        json_payload = {
+            'uninstallReason': uninstall_reason
+        }
+        return self.api.delete(suffix=uuid, json=json_payload)
+
     def update(self, uuid, definition):
         return self.api.post('%s' % uuid, json=definition)
 
