@@ -185,21 +185,27 @@ class ApiTest(unittest.TestCase):
 
     def test_categories(self):
         group = self.rba.categories()
-        assert group
-        expected = ['unit', 'test', 'list']
-        assert expected
+
+        parent = {'id': 123456, 'name': 'unit-test-parent-category'}
+        child = {'id': 789012, 'name': 'unit-test-child-category'}
+
         with requests_mock.Mocker() as m:
+            # we will be doing two posts so mock both results now.
             url = group.api.compute_url()
-            m.post(url, json=expected)
+            m.post(url, [{'json': parent}, {'json': child}])
+
+            # Create a category with no parent ID specified
             actual = group.create(
-                name='unit-test-category-A'
+                name=parent['name']
             )
-            assert actual == expected
+            assert actual == parent
+
+            # Create a category with parent ID specified
             actual = group.create(
-                name='unit-test-category-B',
-                parent_uuid=123456
+                name=child['name'],
+                parent_uuid=parent['id']
             )
-            assert actual == expected
+            assert actual == child
 
     def test_delete_category(self):
         category_group = self.rba.categories()
